┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/tests/testdir.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tests/testdir.h')
-rw-r--r--src/tests/testdir.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/tests/testdir.h b/src/tests/testdir.h
index 0d3c5dd8d..3f244448c 100644
--- a/src/tests/testdir.h
+++ b/src/tests/testdir.h
@@ -20,23 +20,22 @@
#ifndef TESTDIR_H
#define TESTDIR_H
-#include <KTempDir>
-#include <KUrl>
-
+#include <QUrl>
+#include <QTemporaryDir>
#include <QDateTime>
/**
* TestDir provides a temporary directory. In addition to KTempDir, it has
* methods that create files and subdirectories inside the directory.
*/
-class TestDir : public KTempDir
+class TestDir : public QTemporaryDir
{
public:
TestDir(const QString& directoryPrefix = QString());
virtual ~TestDir();
- KUrl url() const;
+ QUrl url() const;
/**
* The following functions create either a file, a list of files, or a directory.
@@ -50,6 +49,7 @@ public:
void createDir(const QString& path, const QDateTime& time = QDateTime());
void removeFile(const QString& path);
+ void removeFiles(const QStringList& files);
private:
void makePathAbsoluteAndCreateParents(QString& path);
@@ -20,23 +20,22 @@
#include <QDateTime>
/**
- * TestDir provides a temporary directory. In addition to KTempDir, it has
+ * TestDir provides a temporary directory. In addition to QTemporaryDir, it has
* methods that create files and subdirectories inside the directory.
*/